==> portkey-ai-0.1.40.tar.gz: portkey-ai-0.1.40/portkey/api_resources/apis.py <==
from typing import Optional, Union, overload, Literal, List
from portkey.api_resources.base_client import APIClient
from .utils import (
    Modes,
    Config,
    retrieve_config,
    Params,
    Message,
    ChatCompletionChunk,
    ChatCompletion,
    TextCompletion,
    TextCompletionChunk,
    ApiType,
)

from .streaming import Stream

__all__ = ["Completions", "ChatCompletions"]


class APIResource:
    _client: APIClient
    # _get: Any
    # _patch: Any
    # _put: Any
    # _delete: Any

    def __init__(self, client: APIClient) -> None:
        self._client = client
        # self._get = client.get
        # self._patch = client.patch
        # self._put = client.put
        # self._delete = client.delete

    def _post(self, *args, **kwargs):
        return self._client.post(*args, **kwargs)


class Completions(APIResource):
    @classmethod
    @overload
    def create(
        cls,
        *,
        prompt: Optional[str] = None,
        config: Optional[Config] = None,
        stream: Literal[True],
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Stream[TextCompletionChunk]:
        ...

    @classmethod
    @overload
    def create(
        cls,
        *,
        prompt: Optional[str] = None,
        config: Optional[Config] = None,
        stream: Literal[False] = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> TextCompletion:
        ...

    @classmethod
    @overload
    def create(
        cls,
        *,
        prompt: Optional[str] = None,
        config: Optional[Config] = None,
        stream: bool = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Union[TextCompletion, Stream[TextCompletionChunk]]:
        ...

    @classmethod
    def create(
        cls,
        *,
        prompt: Optional[str] = None,
        config: Optional[Config] = None,
        stream: bool = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Union[TextCompletion, Stream[TextCompletionChunk]]:
        if config is None:
            config = retrieve_config()
        _client = APIClient(api_key=config.api_key, base_url=config.base_url)
        params = Params(
            prompt=prompt,
            temperature=temperature,
            max_tokens=max_tokens,
            top_k=top_k,
            top_p=top_p,
            **kwargs
        )
        if config.mode == Modes.SINGLE.value:
            return cls(_client)._post(
                "/v1/complete",
                body=config.llms,
                mode=Modes.SINGLE.value,
                params=params,
                cast_to=TextCompletion,
                stream_cls=Stream[TextCompletionChunk],
                stream=stream,
            )
        if config.mode == Modes.FALLBACK.value:
            return cls(_client)._post(
                "/v1/complete",
                body=config.llms,
                mode=Modes.FALLBACK,
                params=params,
                cast_to=TextCompletion,
                stream_cls=Stream[TextCompletionChunk],
                stream=stream,
            )
        if config.mode == Modes.AB_TEST.value:
            return cls(_client)._post(
                "/v1/complete",
                body=config.llms,
                mode=Modes.AB_TEST,
                params=params,
                cast_to=TextCompletion,
                stream_cls=Stream[TextCompletionChunk],
                stream=stream,
            )
        raise NotImplementedError("Mode not implemented.")


class ChatCompletions(APIResource):
    @classmethod
    @overload
    def create(
        cls,
        *,
        messages: Optional[List[Message]] = None,
        config: Optional[Config] = None,
        stream: Literal[True],
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Stream[ChatCompletionChunk]:
        ...

    @classmethod
    @overload
    def create(
        cls,
        *,
        messages: Optional[List[Message]] = None,
        config: Optional[Config] = None,
        stream: Literal[False] = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> ChatCompletion:
        ...

    @classmethod
    @overload
    def create(
        cls,
        *,
        messages: Optional[List[Message]] = None,
        config: Optional[Config] = None,
        stream: bool = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Union[ChatCompletion, Stream[ChatCompletionChunk]]:
        ...

    @classmethod
    def create(
        cls,
        *,
        messages: Optional[List[Message]] = None,
        config: Optional[Config] = None,
        stream: bool = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Union[ChatCompletion, Stream[ChatCompletionChunk]]:
        if config is None:
            config = retrieve_config()
        _client = APIClient(api_key=config.api_key, base_url=config.base_url)
        params = Params(
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
            top_k=top_k,
            top_p=top_p,
            **kwargs
        )
        if config.mode == Modes.SINGLE.value:
            return cls(_client)._post(
                "/v1/chatComplete",
                body=config.llms,
                mode=Modes.SINGLE.value,
                params=params,
                cast_to=ChatCompletion,
                stream_cls=Stream[ChatCompletionChunk],
                stream=stream,
                type=ApiType.CHAT_COMPLETION,
            )
        if config.mode == Modes.FALLBACK.value:
            return cls(_client)._post(
                "/v1/chatComplete",
                body=config.llms,
                mode=Modes.FALLBACK,
                params=params,
                cast_to=ChatCompletion,
                stream_cls=Stream[ChatCompletionChunk],
                stream=stream,
                type=ApiType.CHAT_COMPLETION,
            )
        if config.mode == Modes.AB_TEST.value:
            return cls(_client)._post(
                "/v1/chatComplete",
                body=config.llms,
                mode=Modes.AB_TEST,
                params=params,
                cast_to=ChatCompletion,
                stream_cls=Stream[ChatCompletionChunk],
                stream=stream,
                type=ApiType.CHAT_COMPLETION,
            )
        raise NotImplementedError("Mode not implemented.")

==> portkey-ai-0.1.46.tar.gz: portkey-ai-0.1.46/portkey/api_resources/apis.py <==
from typing import Optional, Union, overload, Literal, List
from portkey.api_resources.base_client import APIClient
from .utils import (
    Modes,
    Config,
    retrieve_config,
    Params,
    Message,
    ChatCompletionChunk,
    ChatCompletion,
    TextCompletion,
    TextCompletionChunk,
    ApiType,
)

from .streaming import Stream

__all__ = ["Completions", "ChatCompletions"]


class APIResource:
    _client: APIClient
    # _get: Any
    # _patch: Any
    # _put: Any
    # _delete: Any

    def __init__(self, client: APIClient) -> None:
        self._client = client
        # self._get = client.get
        # self._patch = client.patch
        # self._put = client.put
        # self._delete = client.delete

    def _post(self, *args, **kwargs):
        return self._client.post(*args, **kwargs)


class Completions(APIResource):
    @classmethod
    @overload
    def create(
        cls,
        *,
        prompt: Optional[str] = None,
        config: Optional[Config] = None,
        stream: Literal[True],
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Stream[TextCompletionChunk]:
        ...

    @classmethod
    @overload
    def create(
        cls,
        *,
        prompt: Optional[str] = None,
        config: Optional[Config] = None,
        stream: Literal[False] = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> TextCompletion:
        ...

    @classmethod
    @overload
    def create(
        cls,
        *,
        prompt: Optional[str] = None,
        config: Optional[Config] = None,
        stream: bool = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Union[TextCompletion, Stream[TextCompletionChunk]]:
        ...

    @classmethod
    def create(
        cls,
        *,
        prompt: Optional[str] = None,
        config: Optional[Config] = None,
        stream: bool = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Union[TextCompletion, Stream[TextCompletionChunk]]:
        if config is None:
            config = retrieve_config()
        _client = APIClient(api_key=config.api_key, base_url=config.base_url)
        params = Params(
            prompt=prompt,
            temperature=temperature,
            max_tokens=max_tokens,
            top_k=top_k,
            top_p=top_p,
            **kwargs
        )
        if config.mode == Modes.SINGLE.value:
            return cls(_client)._post(
                "/v1/complete",
                body=config.llms,
                mode=Modes.SINGLE.value,
                params=params,
                cast_to=TextCompletion,
                stream_cls=Stream[TextCompletionChunk],
                stream=stream,
                _type=ApiType.COMPLETIONS,
            )
        if config.mode == Modes.FALLBACK.value:
            return cls(_client)._post(
                "/v1/complete",
                body=config.llms,
                mode=Modes.FALLBACK,
                params=params,
                cast_to=TextCompletion,
                stream_cls=Stream[TextCompletionChunk],
                stream=stream,
                _type=ApiType.COMPLETIONS,
            )
        if config.mode == Modes.AB_TEST.value:
            return cls(_client)._post(
                "/v1/complete",
                body=config.llms,
                mode=Modes.AB_TEST,
                params=params,
                cast_to=TextCompletion,
                stream_cls=Stream[TextCompletionChunk],
                stream=stream,
                _type=ApiType.COMPLETIONS,
            )
        raise NotImplementedError("Mode not implemented.")


class ChatCompletions(APIResource):
    @classmethod
    @overload
    def create(
        cls,
        *,
        messages: Optional[List[Message]] = None,
        config: Optional[Config] = None,
        stream: Literal[True],
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Stream[ChatCompletionChunk]:
        ...

    @classmethod
    @overload
    def create(
        cls,
        *,
        messages: Optional[List[Message]] = None,
        config: Optional[Config] = None,
        stream: Literal[False] = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> ChatCompletion:
        ...

    @classmethod
    @overload
    def create(
        cls,
        *,
        messages: Optional[List[Message]] = None,
        config: Optional[Config] = None,
        stream: bool = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Union[ChatCompletion, Stream[ChatCompletionChunk]]:
        ...

    @classmethod
    def create(
        cls,
        *,
        messages: Optional[List[Message]] = None,
        config: Optional[Config] = None,
        stream: bool = False,
        temperature: Optional[float] = None,
        max_tokens: Optional[int] = None,
        top_k: Optional[int] = None,
        top_p: Optional[float] = None,
        **kwargs
    ) -> Union[ChatCompletion, Stream[ChatCompletionChunk]]:
        if config is None:
            config = retrieve_config()
        _client = APIClient(api_key=config.api_key, base_url=config.base_url)
        params = Params(
            messages=messages,
            temperature=temperature,
            max_tokens=max_tokens,
            top_k=top_k,
            top_p=top_p,
            **kwargs
        )
        if config.mode == Modes.SINGLE.value:
            return cls(_client)._post(
                "/v1/chatComplete",
                body=config.llms,
                mode=Modes.SINGLE.value,
                params=params,
                cast_to=ChatCompletion,
                stream_cls=Stream[ChatCompletionChunk],
                stream=stream,
                _type=ApiType.CHAT_COMPLETION,
            )
        if config.mode == Modes.FALLBACK.value:
            return cls(_client)._post(
                "/v1/chatComplete",
                body=config.llms,
                mode=Modes.FALLBACK,
                params=params,
                cast_to=ChatCompletion,
                stream_cls=Stream[ChatCompletionChunk],
                stream=stream,
                _type=ApiType.CHAT_COMPLETION,
            )
        if config.mode == Modes.AB_TEST.value:
            return cls(_client)._post(
                "/v1/chatComplete",
                body=config.llms,
                mode=Modes.AB_TEST,
                params=params,
                cast_to=ChatCompletion,
                stream_cls=Stream[ChatCompletionChunk],
                stream=stream,
                _type=ApiType.CHAT_COMPLETION,
            )
        raise NotImplementedError("Mode not implemented.")
